@@ -299,7 +299,7 @@ save_file (GtkamSave *save, const char *filename, CameraFile *file, CameraFileTy
 		msg = g_strdup_printf (_("The file '%s' already exists."),
 				       full_path);
 		if (!save->priv->err_shown) {
-			dialog = gtkam_error_new (GP_ERROR_FILE_EXISTS, NULL, GTK_WIDGET (save), msg);
+			dialog = gtkam_error_new (GP_ERROR_FILE_EXISTS, NULL, GTK_WIDGET (save), "%s", msg);
 			gtk_window_set_transient_for (GTK_WINDOW (dialog),
 						      save->priv->main_window);
 			gtk_widget_show (dialog);
@@ -531,27 +531,23 @@ on_ok_clicked (GtkButton *button, GtkamSave *save)
 				  GP_FILE_TYPE_NORMAL, i + j,
 				  GTKAM_CANCEL (s)->context);
 		if (save->priv->toggle_preview &&
-		    save->priv->toggle_preview->active &&
-		    (!result < 0))
+		    save->priv->toggle_preview->active)
 			result = get_file (save, data->camera,
 				  data->folder, data->name,
 				  GP_FILE_TYPE_PREVIEW, i + j,
 				  GTKAM_CANCEL (s)->context);
 		if (save->priv->toggle_raw &&
-		    save->priv->toggle_raw->active &&
-		    (!result < 0))
+		    save->priv->toggle_raw->active)
 			result = get_file (save, data->camera,
 				  data->folder, data->name, GP_FILE_TYPE_RAW,
 				  i + j, GTKAM_CANCEL (s)->context);
 		if (save->priv->toggle_audio &&
-		    save->priv->toggle_audio->active &&
-		    (!result < 0))
+		    save->priv->toggle_audio->active)
 			result = get_file (save, data->camera,
 				  data->folder, data->name, GP_FILE_TYPE_AUDIO,
 				  i + j, GTKAM_CANCEL (s)->context);
 		if (save->priv->toggle_exif &&
-		    save->priv->toggle_exif->active &&
-		    (!result < 0))
+		    save->priv->toggle_exif->active)
 			result = get_file (save, data->camera,
 				  data->folder, data->name, GP_FILE_TYPE_EXIF,
 				  i + j, GTKAM_CANCEL (s)->context);
